@@ -4,7 +4,7 @@ use warnings;
 
 package Dancer2::Session::MongoDB;
 # ABSTRACT: Dancer 2 session storage with MongoDB
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Moo;
 use MongoDB::MongoClient;
@@ -110,6 +110,12 @@ sub _sessions {
     return [ map { $_->{_id} } $cursor->all ];
 }
 
+sub _change_id {
+    my ( $self, $old_id, $new_id ) = @_;
+    $self->_flush( $new_id, $self->_retrieve( $old_id ) );
+    $self->_destroy( $old_id );
+}
+
 1;
 
 
@@ -127,7 +133,7 @@ Dancer2::Session::MongoDB - Dancer 2 session storage with MongoDB
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
